@@ -6,8 +6,9 @@ package WebService::Gitter;
 use Moo;
 use LWP::UserAgent;
 use JSON::Tiny;
+
 #ABSTRACT: An interface to Gitter REST API via Perl 5.
-our $VERSION = '0.0.1'; # VERSION
+our $VERSION = '0.2.0'; # VERSION
 
 has token_pass => (
     is       => 'ro',
@@ -17,17 +18,26 @@ has token_pass => (
 my $ua = LWP::UserAgent->new;
 $ua->timeout(12);
 $ua->env_proxy;
+
+# these are for the Gitter api links
 my $url_rooms = 'https://api.gitter.im/v1/rooms';
 my $url_user  = 'https://api.gitter.im/v1/user';
 
+# This method send a GET request to a server to get authentication data as the authenticated user.
+
 sub get_user_who {
     my $self = shift;
 
     my $req = $ua->get(
         'https://api.gitter.im/v1/user/me?access_token=' . $self->token_pass );
-
+	
+	my $message = JSON::Tiny::decode_json $req->decoded_content;
     if ( $req->is_success ) {
-        print $req->decoded_content . "\n";
+       
+		foreach my $mes(keys $message) {
+			print "$mes: " . $message->{$mes} . "\n";
+			
+		}
     }
 
     else {
@@ -35,22 +45,22 @@ sub get_user_who {
     }
 }
 
-sub get_room_id {
+# This method send a POST request to the server, to get the room id(and other info). You need to specify $room_uri eg('gitterhq/blah')
+sub post_room_id {
 
-    my ( $self, $uri ) = @_;
+    my ( $self, $room_uri ) = @_;
     my $req = HTTP::Request->new( POST => $url_rooms );
     $req->header( 'Content-Type'  => 'application/json' );
     $req->header( 'Accept'        => 'application/json' );
     $req->header( 'Authorization' => 'Bearer ' . $self->token_pass );
 
-    my $post_body = JSON::Tiny::encode_json( { uri => $uri } );
+    my $post_body = JSON::Tiny::encode_json( { uri => $room_uri } );
     $req->content($post_body);
 
     my $resp = $ua->request($req);
-
+	my $message = JSON::Tiny::decode_json $resp->decoded_content;
     if ( $resp->is_success ) {
-        my $message = $resp->decoded_content;
-        print "Received reply: $message\n";
+        print "Room ID: " . $message->{'id'} . "\n";
     }
 
     else {
@@ -58,6 +68,31 @@ sub get_room_id {
         print "Error message: ", $resp->message, "\n";
     }
 }
+# This method send a message to a room. It needs room id and of course, the text to send.
+    sub post_room_message {
+        my ( $self, $room_id, $text ) = @_;
+        my $req =
+          HTTP::Request->new( POST => $url_rooms . "/$room_id/chatMessages" );
+
+        $req->header( 'Content-Type'  => 'application/json' );
+        $req->header( 'Accept'        => 'application/json' );
+        $req->header( 'Authorization' => 'Bearer ' . $self->token_pass );
+
+        my $post_body = JSON::Tiny::encode_json( { text => $text } );
+        $req->content($post_body);
+
+        my $resp = $ua->request($req);
+
+        if ( $resp->is_success ) {
+            print "Message: text '$text' sent to room with room ID: $room_id\n";
+        }
+
+        else {
+
+            print 'Error code, ' . $resp->code . "\n";
+            print 'Error message, ' . $resp->message . "\n";
+       }
+}
 
 =pod
 
@@ -69,7 +104,7 @@ WebService::Gitter - An interface to Gitter REST API via Perl 5.
 
 =head1 VERSION
 
-version 0.0.1
+version 0.2.0
 
 =head1 SYNOPSIS
 
@@ -81,7 +116,10 @@ version 0.0.1
 	$serv->get_user_who;
 
 	# Prints the info about Gitter room ('Room name')
-	$serv->get_room_ID('FreeCodeCamp/FreeCodeCamp');
+	$serv->get_room_id('FreeCodeCamp/FreeCodeCamp');
+
+	# Send a message to a room
+	$serv->post_room_message('546fd572db8155e6700d6eaf', 'Hi');
 
 =head1 DESCRIPTION
 
